import React, { useState, useEffect } from "react";
import { makeStyles } from "@material-ui/core/styles";
import AppBar from "@material-ui/core/AppBar";
import Toolbar from "@material-ui/core/Toolbar";
import Typography from "@material-ui/core/Typography";
import IconButton from "@material-ui/core/IconButton";
import MenuIcon from "@material-ui/icons/Menu";
import MenuItem from "@material-ui/core/MenuItem";
import Menu from "@material-ui/core/Menu";
import { Container } from "@material-ui/core";
import { useTranslation } from "react-i18next";
import Flag from "react-flags";
import Navigation from "./Navigation";

const useStyles = makeStyles((theme) => ({
  root: {
    flexGrow: 1
  },
  menuButton: {
    marginRight: theme.spacing(2)
  },
  title: {
    flexGrow: 1
  }
}));

const Header = () => {
  const classes = useStyles();
  const { t, i18n } = useTranslation();

  const [anchorEl, setAnchorEl] = useState(null);
  const open = Boolean(anchorEl);

  const [flag, setFlag] = useState({
    name: "RO",
    alt: "-"
  });

  useEffect(() => {
    if (!i18n.language) return;
    setFlag({
      name: i18n.language === "en" ? "GB" : i18n.language.toUpperCase(),
      alt: i18n.language
    });
  }, [i18n.language]);

  const handleMenu = (event) => {
    setAnchorEl(event.currentTarget);
  };

  const handleClose = () => {
    setAnchorEl(null);
  };

  const changeLanguage = (language) => () => {
    if (language != i18n.language) {
      i18n.changeLanguage(language);
    }
    setAnchorEl(null);
  };

  return (
    <div className={classes.root}>
      <AppBar position="static">
        <Toolbar>
          <IconButton
            edge="start"
            className={classes.menuButton}
            color="inherit"
            aria-label="menu"
          >
            <MenuIcon />
          </IconButton>

          <Container>
            <Typography variant="h6" className={classes.title}>
              Reverse proxy
            </Typography>
            <Navigation />
          </Container>

          <div>
            <IconButton
              aria-controls="menu-appbar"
              aria-haspopup="true"
              onClick={handleMenu}
              color="inherit"
            >
              {i18n.language && (
                <Flag
                  name={flag.name}
                  format="png"
                  pngSize={32}
                  shiny={true}
                  basePath="public/flags"
                  alt={flag.alt}
                />
              )}
            </IconButton>

            <Menu
              id="menu-appbar"
              anchorEl={anchorEl}
              anchorOrigin={{
                vertical: "top",
                horizontal: "right"
              }}
              keepMounted
              transformOrigin={{
                vertical: "top",
                horizontal: "right"
              }}
              open={open}
              onClose={handleClose}
            >
              <MenuItem onClick={changeLanguage("ro")}>
                {t("Language.Romanian")}
              </MenuItem>
              <MenuItem onClick={changeLanguage("en")}>
                {t("Language.English")}
              </MenuItem>
            </Menu>
          </div>
        </Toolbar>
      </AppBar>
    </div>
  );
};

export default Header;
