import React from "react";
import { makeStyles } from "@material-ui/core/styles";
import ExpansionPanel from "@material-ui/core/ExpansionPanel";
import ExpansionPanelSummary from "@material-ui/core/ExpansionPanelSummary";
import ExpansionPanelDetails from "@material-ui/core/ExpansionPanelDetails";
import ExpandMoreIcon from "@material-ui/icons/ExpandMore";
import PropTypes from "prop-types";
import Spinner from "../../../components/common/Spinner";
import { useTranslation } from "react-i18next";
import ReleaseNotesSummary from "./ReleaseNotesSummary";
import ReleaseNotesComponent from "./ReleaseNotesComponent";
import styles from "../../../components/common/styles/divStyles";

const useStyles = makeStyles(styles);

const ReleaseNotesListComponent = ({
  releaseNotes,
  handleToggle,
  notesFlags
}) => {
  const classes = useStyles();
  const { t } = useTranslation();

  const getCollapsed = (version) => {
    const flag = notesFlags[version];
    const collapsed = !flag || flag === false;
    return collapsed;
  };

  return (
    <div className={classes.root}>
      <h2>{t("ReleaseNotes.Title")}</h2>
      {releaseNotes.loading ? (
        <Spinner />
      ) : (
        releaseNotes.loaded &&
        releaseNotes.map((note) => {
          return (
            <ExpansionPanel
              key={note.version}
              onChange={handleToggle(note.version)}
            >
              <ExpansionPanelSummary
                expandIcon={<ExpandMoreIcon />}
                id={`panel-${note.version}-header`}
              >
                <ReleaseNotesSummary
                  releaseNote={note}
                  collapsed={getCollapsed(note.version)}
                />
              </ExpansionPanelSummary>
              <ExpansionPanelDetails>
                <ReleaseNotesComponent releaseNote={note} />
              </ExpansionPanelDetails>
            </ExpansionPanel>
          );
        })
      )}
    </div>
  );
};

ReleaseNotesListComponent.propTypes = {
  releaseNotes: PropTypes.array.isRequired,
  handleToggle: PropTypes.func.isRequired,
  notesFlags: PropTypes.object.isRequired
};

export default ReleaseNotesListComponent;
